@@ -6,6 +6,10 @@
  *  Copyright: See COPYING file that comes with this distribution
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "lineranges.h"
 #include <sstream>
 
