@@ -7,4 +7,7 @@ List<Integer> mylist;
 List<List<Integer> > mylist;
 java.io.InputStream iStream ;
 if (argc > 0) { }
-Boolean 0;
\ No newline at end of file
+Boolean 0;
+_myClass c;
+__myClass c;
+__my_Class c;
\ No newline at end of file
